@@ -2266,3 +2266,41 @@ DWORD invokeNppUacOp(const std::wstring& strCmdLineParams)
 
 	return dwError;
 }
+
+bool fileTimeToYMD(const FILETIME& ft, int& yyyymmdd)
+{
+	SYSTEMTIME stUtc;
+	SYSTEMTIME stLocal;
+
+	if (!FileTimeToSystemTime(&ft, &stUtc))
+		return false;
+
+	if (!SystemTimeToTzSpecificLocalTime(NULL, &stUtc, &stLocal))
+		return false;
+
+	yyyymmdd = (stLocal.wYear * 10000) + (stLocal.wMonth * 100) + stLocal.wDay;
+
+	return true;
+}
+
+void expandEnv(wstring& s)
+{
+	wchar_t buffer[MAX_PATH] = { '\0' };
+	// This returns the resulting string length or 0 in case of error.
+	DWORD ret = ExpandEnvironmentStrings(s.c_str(), buffer, static_cast<DWORD>(std::size(buffer)));
+	if (ret != 0)
+	{
+		if (ret == static_cast<DWORD>(lstrlen(buffer) + 1))
+		{
+			s = buffer;
+		}
+		else
+		{
+			// Buffer was too small, try with a bigger buffer of the required size.
+			std::vector<wchar_t> buffer2(ret, 0);
+			ret = ExpandEnvironmentStrings(s.c_str(), buffer2.data(), static_cast<DWORD>(buffer2.size()));
+			assert(ret == static_cast<DWORD>(lstrlen(buffer2.data()) + 1));
+			s = buffer2.data();
+		}
+	}
+}
