@@ -108,6 +108,14 @@ bool SecurityGuard::checkSha256(const std::wstring& filePath, NppModule module2c
 
 // Debug use
 bool doLogCertifError = false;
+const wstring errorLogPath = L"%LOCALAPPDATA%\\Notepad++\\log\\nppComponentCertErrors.log";
+
+void writeCertVerifLog(const wchar_t* logFileName, const wchar_t* log2write)
+{
+	wstring expandedLogFileName = logFileName;
+	expandEnv(expandedLogFileName);
+	writeLog(expandedLogFileName.c_str(), log2write);
+}
 
 bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 {
@@ -117,9 +125,9 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 
 	if (doLogCertifError)
 	{	
-		string dmsg("VerifyLibrary: ");
-		dmsg += wstring2string(filepath, CP_UTF8);
-		writeLog(L"c:\\tmp\\certifError.log", dmsg.c_str());
+		wstring dmsg(L"VerifyComponent: ");
+		dmsg += filepath;
+		writeCertVerifLog(errorLogPath.c_str(), dmsg.c_str());
 	}	
 
 	//
@@ -146,7 +154,7 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		winTEXTrust_data.fdwRevocationChecks = WTD_REVOKE_NONE;
 
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: certificate revocation checking is disabled");
+			writeCertVerifLog(errorLogPath.c_str(), L"VerifyComponent: certificate revocation checking is disabled");
 	}
 	else
 	{
@@ -165,7 +173,7 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 			winTEXTrust_data.fdwRevocationChecks = WTD_REVOKE_NONE;
 
 			if (doLogCertifError)
-				writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: system is offline - certificate revocation won't be checked");
+				writeCertVerifLog(errorLogPath.c_str(), L"VerifyComponent: system is offline - certificate revocation won't be checked");
 		}
 	}
 
@@ -182,7 +190,7 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		if (vtrust)
 		{
 			if (doLogCertifError)
-				writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: trust verification failed");
+				writeCertVerifLog(errorLogPath.c_str(), L"VerifyComponent: trust verification failed");
 
 			return false;
 		}
@@ -190,7 +198,7 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		if (t2)
 		{
 			if (doLogCertifError)
-				writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: error encountered while cleaning up after WinVerifyTrust");
+				writeCertVerifLog(errorLogPath.c_str(), L"VerifyComponent: error encountered while cleaning up after WinVerifyTrust");
 
 			return false;
 		}
@@ -283,7 +291,7 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		key_id_hex = ss.str();
 
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", wstring2string(key_id_hex, CP_UTF8).c_str());
+			writeCertVerifLog(errorLogPath.c_str(), key_id_hex.c_str());
 
 		// Getting the display name			
 		auto sze = ::CertGetNameString(context, CERT_NAME_SIMPLE_DISPLAY_TYPE, 0, NULL, NULL, 0);
@@ -304,16 +312,16 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 	catch (const string& s) {
 		if (doLogCertifError)
 		{
-			string msg = s;
-			msg += " - VerifyLibrary: error while getting certificate information";
-			writeLog(L"c:\\tmp\\certifError.log", msg.c_str());
+			wstring msg = string2wstring(s, CP_UTF8);
+			msg += L" - VerifyComponent: error while getting certificate information";
+			writeCertVerifLog(errorLogPath.c_str(), msg.c_str());
 		}
 		status = false;
 	}
 	catch (...) {
 		// Unknown error
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: error while getting certificate information");
+			writeCertVerifLog(errorLogPath.c_str(), L"VerifyComponent: error while getting certificate information");
 
 		status = false;
 	}
@@ -326,7 +334,15 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		status = false;
 
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: Invalid certificate display name");
+		{
+			wstring msg = L"VerifyComponent - ";
+			msg += L"Invalid certificate display name: ";
+			msg += _signer_display_name;
+			msg += L" vs ";
+			msg += display_name;
+
+			writeCertVerifLog(errorLogPath.c_str(), msg.c_str());
+		}
 	}
 
 	if (status && (_signer_subject != subject))
@@ -334,7 +350,15 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		status = false;
 
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: Invalid certificate subject");
+		{
+			wstring msg = L"VerifyComponent - ";
+			msg += L"Invalid certificate subject: ";
+			msg += _signer_subject;
+			msg += L" vs ";
+			msg += subject;
+
+			writeCertVerifLog(errorLogPath.c_str(), msg.c_str());
+		}
 	}
 
 	if (status && (_signer_key_id != key_id_hex))
@@ -342,7 +366,15 @@ bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 		status = false;
 
 		if (doLogCertifError)
-			writeLog(L"c:\\tmp\\certifError.log", "VerifyLibrary: Invalid certificate key id");
+		{
+			wstring msg = L"VerifyComponent - ";
+			msg += L"Invalid certificate key id: ";
+			msg += _signer_key_id;
+			msg += L" vs ";
+			msg += key_id_hex;
+
+			writeCertVerifLog(errorLogPath.c_str(), msg.c_str());
+		}
 	}
 
 	// Clean up.
