@@ -28,13 +28,13 @@ class MiscSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	MiscSubDlg() = default;
-	~MiscSubDlg() {
+	~MiscSubDlg() override {
 		if (_tipScintillaRenderingTechnology)
 		{
 			::DestroyWindow(_tipScintillaRenderingTechnology);
 			_tipScintillaRenderingTechnology = nullptr;
 		}
-	};
+	}
 
 private :
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
@@ -68,11 +68,14 @@ private:
 
 class TabbarSubDlg : public StaticDialog
 {
+friend class PreferenceDlg;
 public:
 	TabbarSubDlg() = default;
 	void setTabbarAlternateIcons(bool enable = false);
 
 private:
+	HWND _tabCompactLabelLenTip = nullptr;
+
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 };
 
@@ -81,7 +84,7 @@ class EditingSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	EditingSubDlg() = default;
-	~EditingSubDlg() = default;
+	~EditingSubDlg() override = default;
 	
 private :
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
@@ -94,7 +97,7 @@ class Editing2SubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	Editing2SubDlg() = default;
-	~Editing2SubDlg() {
+	~Editing2SubDlg() override {
 		if (_tip != nullptr)
 		{
 			::DestroyWindow(_tip);
@@ -109,7 +112,7 @@ public :
 				tip = nullptr;
 			}
 		}
-	};
+	}
 
 private:
 	HWND _tip = nullptr;
@@ -158,13 +161,13 @@ class MarginsBorderEdgeSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	MarginsBorderEdgeSubDlg() = default;
-	~MarginsBorderEdgeSubDlg() {
+	~MarginsBorderEdgeSubDlg() override {
 		if (_verticalEdgeTip != nullptr)
 		{
 			::DestroyWindow(_verticalEdgeTip);
 			_verticalEdgeTip = nullptr;
 		}
-	};
+	}
 
 private :
 	HWND _verticalEdgeTip = nullptr;
@@ -177,7 +180,7 @@ struct LangID_Name
 {
 	LangType _id = L_TEXT;
 	std::wstring _name;
-	LangID_Name(LangType id, const std::wstring& name) : _id(id), _name(name){};
+	LangID_Name(LangType id, const std::wstring& name) : _id(id), _name(name) {}
 };
 
 class NewDocumentSubDlg : public StaticDialog
@@ -186,11 +189,7 @@ public :
 	NewDocumentSubDlg() = default;
 
 private :
-	void makeOpenAnsiAsUtf8(bool doIt){
-		if (!doIt)
-			::SendDlgItemMessage(_hSelf, IDC_CHECK_OPENANSIASUTF8, BM_SETCHECK, BST_UNCHECKED, 0);
-		::EnableWindow(::GetDlgItem(_hSelf, IDC_CHECK_OPENANSIASUTF8), doIt);
-	};
+	void makeOpenAnsiAsUtf8(bool doIt) const;
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 };
 
@@ -227,7 +226,7 @@ class IndentationSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	IndentationSubDlg() = default;
-	~IndentationSubDlg() {
+	~IndentationSubDlg() override {
 		if (_tipAutoIndentBasic != nullptr)
 		{
 			::DestroyWindow(_tipAutoIndentBasic);
@@ -239,7 +238,7 @@ public :
 			::DestroyWindow(_tipAutoIndentAdvanced);
 			_tipAutoIndentAdvanced = nullptr;
 		}
-	};
+	}
 
 private :
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
@@ -263,13 +262,13 @@ class SearchingSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public:
 	SearchingSubDlg() = default;
-	~SearchingSubDlg() {
+	~SearchingSubDlg() override {
 		if (_tipInSelThresh != nullptr)
 		{
 			::DestroyWindow(_tipInSelThresh);
 			_tipInSelThresh = nullptr;
 		}
-	};
+	}
 
 private:
 	HWND _tipInSelThresh = nullptr;
@@ -323,10 +322,10 @@ class DelimiterSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	DelimiterSubDlg() = default;
-	~DelimiterSubDlg() {
+	~DelimiterSubDlg() override {
 		if (_tip)
 			::DestroyWindow(_tip);
-	};
+	}
 
 private :
 	LONG _gapEditHor = 0;
@@ -365,10 +364,10 @@ class PerformanceSubDlg : public StaticDialog
 friend class PreferenceDlg;
 public :
 	PerformanceSubDlg() = default;
-	~PerformanceSubDlg() {
+	~PerformanceSubDlg() override {
 		if (_largeFileRestrictionTip)
 			::DestroyWindow(_largeFileRestrictionTip);
-	};
+	}
 
 private :
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
@@ -386,17 +385,19 @@ public :
 	void doDialog(bool isRTL = false) {
 		if (!isCreated())
 		{
+			const auto dpiContext = DPIManagerV2::setThreadDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2);
 			create(IDD_PREFERENCE_BOX, isRTL);
 			goToCenter(SWP_SHOWWINDOW | SWP_NOSIZE);
+			DPIManagerV2::setThreadDpiAwarenessContext(dpiContext);
 		}
 		display();
-	};
+	}
 
 	bool renameDialogTitle(const wchar_t *internalName, const wchar_t *newName);
 	
 	int getListSelectedIndex() const {
 		return static_cast<int32_t>(::SendDlgItemMessage(_hSelf, IDC_LIST_DLGTITLE, LB_GETCURSEL, 0, 0));
-	};
+	}
 
 	void showDialogByName(const wchar_t *name) const;
 	bool setListSelection(size_t currentSel) const;
@@ -438,4 +439,3 @@ private :
 
 	ControlInfoTip _gotoTip;
 };
-
