@@ -14,19 +14,21 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-#include <stdio.h>
 #include <windows.h>
+#include <cstring>
+
 #include "StaticDialog.h"
 #include "Common.h"
-//#include "NppDarkMode.h"
+#include "NppDarkMode.h"
+#include "dpiManagerV2.h"
 
 StaticDialog::~StaticDialog()
 {
-	if (isCreated())
+	if (StaticDialog::isCreated())
 	{
 		// Prevent run_dlgProc from doing anything, since its virtual
 		::SetWindowLongPtr(_hSelf, GWLP_USERDATA, 0);
-		destroy();
+		StaticDialog::destroy();
 	}
 }
 
@@ -213,63 +215,154 @@ RECT StaticDialog::getViewablePositionRect(RECT testPositionRc) const
 	return returnRc;
 }
 
-HGLOBAL StaticDialog::makeRTLResource(int dialogID, DLGTEMPLATE **ppMyDlgTemplate)
+[[nodiscard]] static bool dupDlgTemplate(HINSTANCE hInst, int dialogID, std::vector<std::byte>& dlgTemplateData)
 {
 	// Get Dlg Template resource
-	HRSRC  hDialogRC = ::FindResource(_hInst, MAKEINTRESOURCE(dialogID), RT_DIALOG);
+	HRSRC hDialogRC = ::FindResourceW(hInst, MAKEINTRESOURCE(dialogID), RT_DIALOG);
 	if (!hDialogRC)
-		return NULL;
+		return false;
 
-	HGLOBAL  hDlgTemplate = ::LoadResource(_hInst, hDialogRC);
+	HGLOBAL hDlgTemplate = ::LoadResource(hInst, hDialogRC);
 	if (!hDlgTemplate)
-		return NULL;
+		return false;
 
-	const DLGTEMPLATE *pDlgTemplate = static_cast<DLGTEMPLATE *>(::LockResource(hDlgTemplate));
+	const auto* pDlgTemplate = static_cast<DLGTEMPLATE*>(::LockResource(hDlgTemplate));
 	if (!pDlgTemplate)
-		return NULL;
+		return false;
 
 	// Duplicate Dlg Template resource
-	unsigned long sizeDlg = ::SizeofResource(_hInst, hDialogRC);
-	HGLOBAL hMyDlgTemplate = ::GlobalAlloc(GPTR, sizeDlg);
-	if (!hMyDlgTemplate) return nullptr;
+	const size_t sizeDlg = ::SizeofResource(hInst, hDialogRC);
+	dlgTemplateData.resize(sizeDlg);
+	::memcpy(dlgTemplateData.data(), pDlgTemplate, sizeDlg);
 
-	*ppMyDlgTemplate = static_cast<DLGTEMPLATE *>(::GlobalLock(hMyDlgTemplate));
-	if (!*ppMyDlgTemplate) return nullptr;
-
-	::memcpy(*ppMyDlgTemplate, pDlgTemplate, sizeDlg);
-
-	DLGTEMPLATEEX* pMyDlgTemplateEx = reinterpret_cast<DLGTEMPLATEEX *>(*ppMyDlgTemplate);
-	if (!pMyDlgTemplateEx) return nullptr;
-
-	if (pMyDlgTemplateEx->signature == 0xFFFF)
-		pMyDlgTemplateEx->exStyle |= WS_EX_LAYOUTRTL;
-	else
-		(*ppMyDlgTemplate)->dwExtendedStyle |= WS_EX_LAYOUTRTL;
-
-	return hMyDlgTemplate;
+	return true;
 }
 
-void StaticDialog::create(int dialogID, bool isRTL, bool msgDestParent)
+[[nodiscard]] static bool setRTLResource(std::vector<std::byte>& dlgTemplateData)
 {
-	if (isRTL)
+	auto* pMyDlgTemplateEx = reinterpret_cast<DLGTEMPLATEEX*>(dlgTemplateData.data());
+	if (!pMyDlgTemplateEx)
+		return false;
+
+	if (pMyDlgTemplateEx->signature == 0xFFFF && pMyDlgTemplateEx->dlgVer == 1)
 	{
-		DLGTEMPLATE *pMyDlgTemplate = NULL;
-		HGLOBAL hMyDlgTemplate = makeRTLResource(dialogID, &pMyDlgTemplate);
-		_hSelf = ::CreateDialogIndirectParam(_hInst, pMyDlgTemplate, _hParent, dlgProc, reinterpret_cast<LPARAM>(this));
-		::GlobalFree(hMyDlgTemplate);
+		pMyDlgTemplateEx->exStyle |= WS_EX_LAYOUTRTL;
 	}
 	else
-		_hSelf = ::CreateDialogParam(_hInst, MAKEINTRESOURCE(dialogID), _hParent, dlgProc, reinterpret_cast<LPARAM>(this));
+	{
+		auto* pMyDlgTemplate = reinterpret_cast<DLGTEMPLATE*>(dlgTemplateData.data());
+		pMyDlgTemplate->dwExtendedStyle |= WS_EX_LAYOUTRTL;
+	}
+
+	return true;
+}
+
+// inspired by https://stackoverflow.com/questions/14370238
+[[nodiscard]] static std::byte* skipSz(std::byte* pData)
+{
+	auto* str = reinterpret_cast<WCHAR*>(pData); // string
+	const size_t length = std::wcslen(str);
+	return reinterpret_cast<std::byte*>(str + length + 1);
+}
+
+[[nodiscard]] static std::byte* skipSzOrOrd(std::byte* pData)
+{
+	auto* ptrElement = reinterpret_cast<WORD*>(pData);
+
+	if (*ptrElement == 0xFFFF) // ordinal
+	{
+		ptrElement += 2;
+	}
+	else // string or no element, same as skipSz
+	{
+		const auto* str = reinterpret_cast<WCHAR*>(ptrElement);
+		ptrElement += (std::wcslen(str) + 1);
+	}
+
+	return reinterpret_cast<std::byte*>(ptrElement);
+}
+
+[[nodiscard]] static int setFontResource(std::vector<std::byte>& dlgTemplateData, WORD fontSize)
+{
+	enum result { failed = -1, noFont, success };
+
+	auto* pMyDlgTemplateEx = reinterpret_cast<DLGTEMPLATEEX*>(dlgTemplateData.data());
+	if (!pMyDlgTemplateEx || pMyDlgTemplateEx->signature != 0xFFFF || pMyDlgTemplateEx->dlgVer != 1)
+		return failed;
+
+	// No need to check DS_SHELLFONT, as it already includes DS_SETFONT (DS_SETFONT | DS_FIXEDSYS)
+	if ((pMyDlgTemplateEx->style & DS_SETFONT) != DS_SETFONT)
+		return noFont; // allow RTL set before
+
+	auto* pData = reinterpret_cast<std::byte*>(pMyDlgTemplateEx);
+	pData += sizeof(DLGTEMPLATEEX);
+	// sz_Or_Ord menu
+	pData = skipSzOrOrd(pData);
+	// sz_Or_Ord windowClass;
+	pData = skipSzOrOrd(pData);
+	// WCHAR title[titleLen]
+	pData = skipSz(pData);
+	// WORD pointSize;
+	auto* pointSize = reinterpret_cast<WORD*>(pData);
+	if (fontSize > 0)
+	{
+		*pointSize = static_cast<WORD>(DPIManagerV2::scaleFontForFactor(fontSize));
+	}
+
+	return success;
+}
+
+[[nodiscard]] static bool modifyResource(
+	HINSTANCE hInst,
+	int dialogID,
+	std::vector<std::byte>& dlgTemplateData,
+	bool isRTL,
+	WORD fontSize)
+{
+	if (!dupDlgTemplate(hInst, dialogID, dlgTemplateData))
+		return false;
+
+	if (isRTL && !setRTLResource(dlgTemplateData))
+		return false;
+
+	if (fontSize != 0 && setFontResource(dlgTemplateData, fontSize) < 0)
+		return false;
+
+	return true;
+}
+
+HWND StaticDialog::myCreateDialogIndirectParam(int dialogID, bool isRTL, WORD fontSize, DLGPROC myDlgProc)
+{
+	std::vector<std::byte> dlgTemplateData;
+
+	if (!modifyResource(_hInst, dialogID, dlgTemplateData, isRTL, fontSize))
+		return ::CreateDialogParam(_hInst, MAKEINTRESOURCE(dialogID), _hParent, myDlgProc, reinterpret_cast<LPARAM>(this));
+
+	return ::CreateDialogIndirectParam(_hInst, reinterpret_cast<DLGTEMPLATE*>(dlgTemplateData.data()), _hParent, myDlgProc, reinterpret_cast<LPARAM>(this));
+}
+
+INT_PTR StaticDialog::myCreateDialogBoxIndirectParam(int dialogID, bool isRTL, WORD fontSize)
+{
+	std::vector<std::byte> dlgTemplateData;
+
+	if (!modifyResource(_hInst, dialogID, dlgTemplateData, isRTL, fontSize))
+		return ::DialogBoxParam(_hInst, MAKEINTRESOURCE(dialogID), _hParent, dlgProc, reinterpret_cast<LPARAM>(this));
+
+	return ::DialogBoxIndirectParam(_hInst, reinterpret_cast<DLGTEMPLATE*>(dlgTemplateData.data()), _hParent, dlgProc, reinterpret_cast<LPARAM>(this));
+}
+
+void StaticDialog::create(int dialogID, bool isRTL, bool msgDestParent, WORD fontSize)
+{
+	_hSelf = StaticDialog::myCreateDialogIndirectParam(dialogID, isRTL, fontSize);
 
 	if (!_hSelf)
 	{
-		generic_string errMsg = TEXT("CreateDialogParam() return NULL.\rGetLastError(): ");
+		std::wstring errMsg = L"CreateDialogParam() return NULL.\rGetLastError(): ";
 		errMsg += GetLastErrorAsString();
-		::MessageBox(NULL, errMsg.c_str(), TEXT("In StaticDialog::create()"), MB_OK);
+		::MessageBox(NULL, errMsg.c_str(), L"In StaticDialog::create()", MB_OK);
 		return;
 	}
 
-	NppDarkMode::setDarkTitleBar(_hSelf);
 	setDpi();
 
 	// if the destination of message NPPM_MODELESSDIALOG is not its parent, then it's the grand-parent
@@ -302,4 +395,3 @@ intptr_t CALLBACK StaticDialog::dlgProc(HWND hwnd, UINT message, WPARAM wParam,
 		}
 	}
 }
-
