@@ -28,7 +28,7 @@ LocalizationSwitcher::LocalizationDefinition localizationDefs[] =
 	{L"Español",                L"spanish.xml"},
 	{L"Italiano",               L"italian.xml"},
 	{L"Português",              L"portuguese.xml"},
-	{L"Português brasileiro",   L"brazilian_portuguese.xml"},
+	{L"Português (Brasil)",     L"brazilian_portuguese.xml"},
 	{L"Nederlands",             L"dutch.xml"},
 	{L"Русский",                L"russian.xml"},
 	{L"Polski",                 L"polish.xml"},
@@ -62,7 +62,7 @@ LocalizationSwitcher::LocalizationDefinition localizationDefs[] =
 	{L"Hrvatski",               L"croatian.xml"},
 	{L"ქართული ენა",            L"georgian.xml"},
 	{L"Euskara",                L"basque.xml"},
-	{L"Español argentina",      L"spanish_ar.xml"},
+	{L"Español (Argentina)",    L"spanish_ar.xml"},
 	{L"Беларуская мова",        L"belarusian.xml"},
 	{L"Srpski",                 L"serbian.xml"},
 	{L"Cрпски",                 L"serbianCyrillic.xml"},
@@ -104,7 +104,7 @@ LocalizationSwitcher::LocalizationDefinition localizationDefs[] =
 	{L"Corsu",                  L"corsican.xml"},
 	{L"Brezhoneg",              L"breton.xml"},
 	{L"کوردی‬",            L"kurdish.xml"},
-	{L"Pig latin",              L"piglatin.xml"},
+	{L"Pig Latin",              L"piglatin.xml"},
 	{L"Zulu",                   L"zulu.xml"},
 	{L"Vèneto",                 L"venetian.xml"},
 	{L"Gaeilge",                L"irish.xml"},
